@@ -38,6 +38,9 @@ class RestClient(object):
         self.check_resource(resource_name)
         self.request_timeout = request_timeout
 
+    def update_token(self, token):
+        self.headers["Authorization"] = self.get_token_header(token)
+
     def add_workspace(self, data, url=None):
         """
         Add workspace uuid to the data.
@@ -174,7 +177,7 @@ class RestClient(object):
         # as the self.endpoint can be different size
         result = requests.post(
             ENDPOINT + "authorization/v2/authorize",
-            data=json.dumps({"service": resource_name}),
+            data=json.dumps({"service": resource_name, "call_type": "authenticate"}),
             headers=self.headers,
             timeout=10,
         )
@@ -350,14 +353,15 @@ class RestClient(object):
         except Exception as e:
             raise Exception("Unable to read base64:" + str(e))
 
-    def load_url_image(self, path, resize=True):
+    def load_url_image(self, path, resize=True, timeout=30):
         """
         Load url file to base64 WITHOUT resizing (it is used in upload image for recognition).
         :param path: url path
         :param resize: if we want to resize image
+        :param timeout: request timeout in seconds
         :return: base64 encoded string
         """
-        r = requests.get(str(path), headers={"Accept": "*/*", "User-Agent": "request"})
+        r = requests.get(str(path), headers={"Accept": "*/*", "User-Agent": "request"}, timeout=timeout)
         img_bin = r.content
         image = np.asarray(bytearray(img_bin), dtype="uint8")
         image = cv2.imdecode(image, cv2.IMREAD_COLOR)
@@ -481,7 +485,6 @@ class RestClient(object):
                     self.update_status(status, result)
                     results.append(result)
                     pbar.update(future["size"])
-            print(status)
         else:
             results = [future["future"].result() for future in futures]
         return results
