@@ -157,7 +157,7 @@ class RecognitionClient(RestClient):
         """
         return self.post(IMAGE_ENDPOINT + image_id + "/add-label/", data={LABEL_ID: label_id})
 
-    def get_training_images(self, page_url=None, verification=None):
+    def get_training_images(self, page_url=None, verification=None, test=False):
         """
         Get paginated result of images from workspace.
         :param page_url: optional, select the specific page of images, default first page
@@ -171,6 +171,9 @@ class RecognitionClient(RestClient):
         )
         url += "&verified=" + str(verification) if verification is not None else ""
 
+        if test:
+            url += "&test=true"
+
         result = self.get(url)
         return (
             [Image(self.token, self.endpoint, image_json) for image_json in result[RESULTS]],
@@ -178,13 +181,14 @@ class RecognitionClient(RestClient):
             {"count": result["count"], STATUS: "ok"},
         )
 
-    def training_images_iter(self, verification=None, batch_size=1):
+    def training_images_iter(self, page_url=None, verification=None, batch_size=1, test=False):
         """
         Get iterator overall all of images from workspace.
+        :param page_url: optional, can add new parameters or select different than first page
         :param verification: optional, integer which says how many verifications should have the images
         :return: iterator
         """
-        images, next_page, status = self.get_training_images(verification=verification)
+        images, next_page, status = self.get_training_images(page_url=page_url, verification=verification, test=test)
         while images:
             for image in self.batch(images, batch_size):
                 if batch_size == 1:
@@ -284,14 +288,14 @@ class RecognitionClient(RestClient):
             return None, {STATUS: msg}
         return Task(self.token, self.endpoint, task_json), RESULT_OK
 
-    def create_label(self, name, description=None, label_type=CATEGORY):
+    def create_label(self, name, description=None, output_name=None, label_type=CATEGORY):
         """
         Create label with given name.
         :param name: name of the label
         :param label_type: type of label to create (category or tag)
         :return: Label object, status
         """
-        data = {NAME: name, LABEL_TYPE: label_type, DESCRIPTION: description}
+        data = {NAME: name, LABEL_TYPE: label_type, DESCRIPTION: description, OUTPUT_NAME: output_name}
         label_json = self.post(LABEL_ENDPOINT, data=data)
         if ID not in label_json:
             return None, {STATUS: "unexpected error"}
@@ -397,7 +401,7 @@ class RecognitionClient(RestClient):
             result = client.classify_on_task({'_url':'__SOME_IMG_URL__'}, task_id="__UUID__")
 
         :param records: array of json/dicts [{'_url':'url-path'}, {'_file': ''}, {'_base64': 'base64encodeimg'}]
-        :param task_id: id of task 
+        :param task_id: id of task
         :param version: optional(integer of specific version), default None/production_version
         :param store_images: if true then store the images on the backend (available in higher plans)
         :return: json response
@@ -600,7 +604,7 @@ class Label(RecognitionClient):
     # TODO: get object count
     # TODO: get objects of given label
 
-    def get_training_images(self, page_url=None, verification=None, not_label=False):
+    def get_training_images(self, page_url=None, verification=None, not_label=False, test=False):
         """
         Get paginated result of images for specific label.
 
@@ -611,9 +615,9 @@ class Label(RecognitionClient):
             if not_label:
                 page_url = IMAGE_ENDPOINT + "?not_labels=" + self.id
             else:
-                page_url = IMAGE_ENDPOINT + "?label=" + self.id
+                page_url = IMAGE_ENDPOINT + "?labels=" + self.id
 
-        return super().get_training_images(page_url=page_url, verification=verification)
+        return super().get_training_images(page_url=page_url, verification=verification, test=test)
 
     def upload_images(self, records):
         """
@@ -643,7 +647,7 @@ class Label(RecognitionClient):
         """
         Add task to this label.
         ! this is only for ANNOTATE (parent => child mapping behaviour)
-        
+
         :param task_id: identification of label
         :return: json/dict result
         """
